/***************************************
 *                                     *
 *  Даден е неориентиран мултиграф     *
 *  Да се намери най-малко колко ребра *
 *  трябва да се премахнат, така че    *                                              *
 *  полученият граф да не бъде свързан *
 *                                     *
 ***************************************
*/

#include <iostream>
#include <vector>
#include <queue>
#include <cstring>

using namespace std;

const int INF =1000000;
const int NMAX = 101;
const int MMAX = 10000;


struct edge
{ int u,v;
  int f,c,d;
};


int n,m;
edge e[2*MMAX];
vector<int> a[NMAX], b[NMAX];

void init()
{
  cin >> n;
  cin >> m;
  for(int i=0; i<m; i++)
  { int u,v;
    cin >> u >> v;
    e[i].u = u; e[i].v = v;
    e[m+i].u = v; e[m+i].v = u;
  }
  m = 2*m;
  for(int i=0; i<m; i++)
  { a[e[i].u].push_back(i);
    b[e[i].v].push_back(i);
  }
}


int flow;

bool vis[NMAX];
int pred[NMAX];
int last[NMAX];

bool bfs(int s, int t)
{ memset(vis,0,sizeof(bool)*(n+1));
  memset(pred,0,sizeof(int)*(n+1));
  memset(last,0,sizeof(int)*(n+1));

  queue<int> q;
  q.push(s);
  vis[s] = true;
  pred[s] = 0;
  last[s] = 0;

  while(!q.empty() and !vis[t])
  { int u = q.front(); q.pop();

    for(int i: a[u])
    { int v = e[i].v;
      if(!vis[v] and e[i].f<e[i].c)
      { q.push(v);
        vis[v]=true;
        pred[v] = u;
        last[v] = i;
        e[i].d = e[i].c-e[i].f;
      }
    }

    int v = u;
    for(int i: b[v])
    { int u = e[i].u;
      if(!vis[u] and e[i].f>0)
      { q.push(u);
        vis[u]=true;
        pred[u] = v;
        last[u] = i;
        e[i].d = e[i].f;
      }
    }
  }

  return vis[t];
}

void update_flow(int s, int t)
{ int dmin = INF;
  int v = t;
  while(v!=s)
  { int i = last[v];
    if(dmin>e[i].d) dmin=e[i].d;
    v = pred[v];
  }

  v = t;
  while(v!=s)
  { int i = last[v];
    if(e[i].v==v)
      e[i].f += dmin;
    else
      e[i].f -= dmin;
    v = pred[v];
  }

  flow = flow + dmin;
}

void maxflow(int s, int t)
{ for(int i=0; i<m; i++)
  { e[i].c = 1;
    e[i].f = 0;
    e[i].d = 0;
  }

  flow = 0;
  while(bfs(s,t))
    update_flow(s,t);
}

int main()
{
  init();

  int f = m;
  for(int t=2; t<=n; t++)
  { maxflow(1,t);
    if(f>flow) f=flow;
  }
  cout << f << endl;
  return 0;
}
